@@ -5,7 +5,7 @@ use warnings;
 use Carp ();
 use Scalar::Util qw/blessed weaken/;
 
-use Mouse::Util qw/get_code_info not_supported load_class/;
+use Mouse::Util qw/:meta get_code_info not_supported load_class/;
 
 {
     my %METACLASS_CACHE;
@@ -24,7 +24,7 @@ use Mouse::Util qw/get_code_info not_supported load_class/;
             || $class->throw_error("You must pass a package name and it cannot be blessed");
 
         return $METACLASS_CACHE{$package_name}
-            ||= $class->_new(package => $package_name, @args);
+            ||= $class->_construct_meta(package => $package_name, @args);
     }
 
     sub class_of{
@@ -46,12 +46,9 @@ use Mouse::Util qw/get_code_info not_supported load_class/;
 
 }
 
-sub meta{ Mouse::Meta::Class->initialize(ref $_[0] || $_[0]) }
-
 sub _new{ Carp::croak("Mouse::Meta::Module is an abstract class") }
 
 sub name { $_[0]->{package} }
-sub _method_map{ $_[0]->{methods} }
 
 sub version   { no strict 'refs'; ${shift->name.'::VERSION'}   }
 sub authority { no strict 'refs'; ${shift->name.'::AUTHORITY'} }
@@ -82,13 +79,17 @@ sub add_method {
     my($self, $name, $code) = @_;
 
     if(!defined $name){
-        $self->throw_error("You must pass a defined name");
+        $self->throw_error('You must pass a defined name');
     }
+    if(!defined $code){
+        $self->throw_error('You must pass a defined code');
+    }
+
     if(ref($code) ne 'CODE'){
         not_supported 'add_method for a method object';
     }
 
-    $self->_method_map->{$name}++; # Moose stores meta object here.
+    $self->{methods}->{$name}++; # Moose stores meta object here.
 
     my $pkg = $self->name;
     no strict 'refs';
@@ -101,15 +102,16 @@ sub _code_is_mine { # taken from Class::MOP::Class
 
     my ( $code_package, $code_name ) = get_code_info($code);
 
-    return $code_package && $code_package eq $self->name
+    return $code_package && $code_package eq $self->{package}
         || ( $code_package eq 'constant' && $code_name eq '__ANON__' );
 }
 
 sub has_method {
     my($self, $method_name) = @_;
 
-    return 1 if $self->_method_map->{$method_name};
-    my $code = $self->name->can($method_name);
+    return 1 if $self->{methods}->{$method_name};
+
+    my $code = $self->{package}->can($method_name);
 
     return $code && $self->_code_is_mine($code);
 }
@@ -298,6 +300,7 @@ __END__
 
 =head1 NAME
 
-Mouse::Meta::Module - Common base class for Mouse::Meta::Class and Mouse::Meta::Role
+Mouse::Meta::Module - The base class for Mouse::Meta::Class and Mouse::Meta::Role
 
 =cut
+
