@@ -7,7 +7,7 @@ use overload '""'     => sub { shift->{name} },   # stringify to tc name
 
 use Carp ();
 
-use Mouse::Util ();
+use Mouse::Util qw(:meta);
 
 sub new {
     my $class = shift;
@@ -84,7 +84,7 @@ __END__
 
 =head1 NAME
 
-Mouse::Meta::TypeConstraint - The Mouse Type Constraint Metaclass
+Mouse::Meta::TypeConstraint - The Mouse Type Constraint metaclass
 
 =head1 DESCRIPTION
 
@@ -106,5 +106,9 @@ Don't use this.
 
 =back
 
+=head1 SEE ALSO
+
+L<Moose::Meta::TypeConstraint>
+
 =cut
 
