@@ -1,28 +1,32 @@
 package Mouse::Util;
 use strict;
 use warnings;
-use base qw/Exporter/;
+
+use Exporter;
 
 use Carp qw(confess);
-use B ();
 
+our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
     find_meta
     does_role
     resolve_metaclass_alias
+    apply_all_roles
     english_list
 
     load_class
     is_class_loaded
 
-    apply_all_roles
-    not_supported
-
     get_linear_isa
     get_code_info
+
+    not_supported
+
+    does meta dump
 );
 our %EXPORT_TAGS = (
     all  => \@EXPORT_OK,
+    meta => [qw(does meta dump)],
 );
 
 # Moose::Util compatible utilities
@@ -32,13 +36,14 @@ sub find_meta{
 }
 
 sub does_role{
-    my ($class_or_obj, $role) = @_;
+    my ($class_or_obj, $role_name) = @_;
 
     my $meta = Mouse::Meta::Module::class_of($class_or_obj);
 
-    return 0 unless defined $meta;
-    return 1 if $meta->does_role($role);
-    return 0;
+    (defined $role_name)
+        || ($meta || 'Mouse::Meta::Class')->throw_error("You must supply a role name to does()");
+
+    return defined($meta) && $meta->does_role($role_name);
 }
 
 
@@ -91,6 +96,8 @@ BEGIN {
         my ($coderef) = @_;
         ref($coderef) or return;
 
+        require B;
+
         my $cv = B::svref_2object($coderef);
         $cv->isa('B::CV') or return;
 
@@ -145,7 +152,6 @@ sub load_first_existing_class {
     my @classes = @_
       or return;
 
-    my $found;
     my %exceptions;
     for my $class (@classes) {
         my $e = _try_load_one_class($class);
@@ -154,12 +160,11 @@ sub load_first_existing_class {
             $exceptions{$class} = $e;
         }
         else {
-            $found = $class;
-            last;
+            return $class;
         }
     }
-    return $found if $found;
 
+    # not found
     confess join(
         "\n",
         map {
@@ -245,7 +250,7 @@ sub apply_all_roles {
         if ($i + 1 < $max && ref($_[$i + 1])) {
             push @roles, [ $_[$i++] => $_[$i] ];
         } else {
-            push @roles, [ $_[$i] => {} ];
+            push @roles, [ $_[$i]   => undef ];
         }
         my $role_name = $roles[-1][0];
         load_class($role_name);
@@ -276,15 +281,35 @@ sub english_list {
     return join q{, }, @items, "and $tail";
 }
 
+
+# common utilities
+
 sub not_supported{
     my($feature) = @_;
 
     $feature ||= ( caller(1) )[3]; # subroutine name
 
-    local $Carp::CarpLevel = $Carp::CarpLevel + 2;
-    Carp::croak("Mouse does not currently support $feature");
+    local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+    Carp::confess("Mouse does not currently support $feature");
 }
 
+sub meta{
+    return Mouse::Meta::Class->initialize($_[0]);
+}
+
+sub dump { 
+    my($self, $maxdepth) = @_;
+
+    require 'Data/Dumper.pm'; # we don't want to create its namespace
+    my $dd = Data::Dumper->new([$self]);
+    $dd->Maxdepth(defined($maxdepth) ? $maxdepth : 2);
+    $dd->Indent(1);
+    return $dd->Dump();
+}
+
+sub does :method;
+*does = \&does_role; # alias
+
 1;
 
 __END__
@@ -295,9 +320,59 @@ Mouse::Util - features, with or without their dependencies
 
 =head1 IMPLEMENTATIONS FOR
 
-=head2 L<MRO::Compat>
+=head2 Moose::Util
 
-=head3 get_linear_isa
+=head3 C<find_meta>
+
+=head3 C<does_role>
+
+=head3 C<resolve_metaclass_alias>
+
+=head3 C<apply_all_roles>
+
+=head3 C<english_list>
+
+=head2 Class::MOP
+
+=head2 C<< is_class_loaded(ClassName) -> Bool >>
+
+Returns whether C<ClassName> is actually loaded or not. It uses a heuristic which
+involves checking for the existence of C<$VERSION>, C<@ISA>, and any
+locally-defined method.
+
+=head3 C<< load_class(ClassName) >>
+
+This will load a given C<ClassName> (or die if it's not loadable).
+This function can be used in place of tricks like
+C<eval "use $module"> or using C<require>.
+
+=head2 MRO::Compat
+
+=head3 C<get_linear_isa>
+
+=head2 Sub::Identify
+
+=head3 C<get_code_info>
+
+=head1 UTILITIES FOR MOUSE
+
+=over 4
+
+=item *
+
+C<not_supported>
+
+=back
+
+=head1 SEE ALSO
+
+L<Moose::Util>
+
+L<Scalar::Util>
+
+L<Sub::Identify>
+
+L<MRO::Compat>
 
 =cut
 
